@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2020 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -179,7 +179,7 @@ typedef struct fcml_st_def_addr_mode_desc {
 } fcml_st_def_addr_mode_desc;
 
 /* Instruction code definition for multi-instructions. Currently only the
- * instructions with suffixes uses this mechanism.
+ * instructions with suffixes use this mechanism.
  */
 typedef struct fcml_st_def_instruction_code_desc {
     /* Instruction code.*/
@@ -228,18 +228,16 @@ typedef struct fcml_st_def_instruction_desc {
 #define FCML_DEF_PREFIX_L_1(x)                       FCML_TP_GET_BIT(x,5)
 #define FCML_DEF_PREFIX_L_0(x)                       FCML_TP_GET_BIT(x,6)
 #define FCML_DEF_PREFIX_VEX_REQ(x)                   FCML_TP_GET_BIT(x,7)
-/* Currently unused probably can be reused in the future. */
-#define FCML_DEF_PREFIX_RESERVED(x)                  FCML_TP_GET_BIT(x,8)
-#define FCML_DEF_PREFIX_L_IGNORE_OS(x)               FCML_TP_GET_BIT(x,9)
-#define FCML_DEF_PREFIX_XOP_REQ(x)                   FCML_TP_GET_BIT(x,10)
-#define FCML_DEF_PREFIX_HLE_ENABLED(x)               FCML_TP_GET_BIT(x,11)
-#define FCML_DEF_PREFIX_MANDATORY_66(x)              FCML_TP_GET_BIT(x,12)
-#define FCML_DEF_PREFIX_MANDATORY_F2(x)              FCML_TP_GET_BIT(x,13)
-#define FCML_DEF_PREFIX_MANDATORY_F3(x)              FCML_TP_GET_BIT(x,14)
-#define FCML_DEF_PREFIX_SUFFIX(x)                    FCML_TP_GET_BIT(x,15)
-#define FCML_DEF_PREFIX_EVEX_REQ(x)                  FCML_TP_GET_BIT(x,16)
-#define FCML_DEF_PREFIX_L_prim_1(x)                  FCML_TP_GET_BIT(x,17)
-#define FCML_DEF_PREFIX_L_prim_0(x)                  FCML_TP_GET_BIT(x,18)
+#define FCML_DEF_PREFIX_L_IGNORE_OS(x)               FCML_TP_GET_BIT(x,8)
+#define FCML_DEF_PREFIX_XOP_REQ(x)                   FCML_TP_GET_BIT(x,9)
+#define FCML_DEF_PREFIX_HLE_ENABLED(x)               FCML_TP_GET_BIT(x,10)
+#define FCML_DEF_PREFIX_MANDATORY_66(x)              FCML_TP_GET_BIT(x,11)
+#define FCML_DEF_PREFIX_MANDATORY_F2(x)              FCML_TP_GET_BIT(x,12)
+#define FCML_DEF_PREFIX_MANDATORY_F3(x)              FCML_TP_GET_BIT(x,13)
+#define FCML_DEF_PREFIX_SUFFIX(x)                    FCML_TP_GET_BIT(x,14)
+#define FCML_DEF_PREFIX_EVEX_REQ(x)                  FCML_TP_GET_BIT(x,15)
+#define FCML_DEF_PREFIX_L_prim_1(x)                  FCML_TP_GET_BIT(x,16)
+#define FCML_DEF_PREFIX_L_prim_0(x)                  FCML_TP_GET_BIT(x,17)
 
 #define FCML_DEF_PREFIX_IS_AVX_REQ(x)   (FCML_DEF_PREFIX_VEX_REQ(x) || \
     FCML_DEF_PREFIX_EVEX_REQ(x) || FCML_DEF_PREFIX_XOP_REQ(x))
@@ -251,6 +249,8 @@ typedef struct fcml_st_def_instruction_desc {
 #define FCML_DEF_OPCODE_FLAGS_OPCODE_FIELD_REG(x)           ((x) & 0x00000001)
 #define FCML_DEF_OPCODE_FLAGS_OPCODE_FIELD_W(x)             ((x) & 0x00000002)
 #define FCML_DEF_OPCODE_FLAGS_OPCODE_FIELD_S(x)             ((x) & 0x00000004)
+/* tttn field for conditional instructions, specifies a condition
+ * asserted or negated. The field is located in opcode byte. */
 #define FCML_DEF_OPCODE_FLAGS_OPCODE_FIELD_TTTN(x)          ((x) & 0x00000040)
 #define FCML_DEF_OPCODE_FLAGS_64BITS_EOSA_BY_DEFAULT(x)     ((x) & 0x00000080)
 #define FCML_DEF_OPCODE_FLAGS_POS(x)                  (((x) & 0x00000700) >> 8)
@@ -288,8 +288,9 @@ typedef struct fcml_st_def_instruction_desc {
 #define FCML_OP_IMM(encoded_size, encoded_ex_size)   (FCML_OP_IMM_BASE | \
         (encoded_size) << 8 | (encoded_ex_size))
 
-#define FCML_OP_IMM_64    (FCML_OP_IMM_BASE | 1 << 16 | FCML_EOS_EOSA << 8 | \
-        FCML_EOS_UNDEFINED)
+#define FCML_OP_IMM_64_ALLOWED  1 << 16
+#define FCML_OP_IMM_64   (FCML_OP_IMM(FCML_EOS_EOSA, FCML_EOS_UNDEFINED) | \
+        FCML_OP_IMM_64_ALLOWED)
 
 /* Register explicitly set.*/
 #define FCML_OP_EXPLICIT_REG_BASE 0x02000000
@@ -349,7 +350,7 @@ typedef struct fcml_st_def_instruction_desc {
 
 #define FCML_OP_RM_BASE                                0x09000000
 #define FCML_OP_RM(reg_type, encoded_register_operand_size, \
-        encoded_memory_operand_size, flags )        (FCML_OP_RM_BASE | \
+        encoded_memory_operand_size, flags)        (FCML_OP_RM_BASE | \
                 ((encoded_memory_operand_size) << 16) | \
                 ((encoded_register_operand_size) << 8) | ((reg_type) << 4) | \
                 (flags))
@@ -382,7 +383,6 @@ typedef struct fcml_st_def_instruction_desc {
 
 #define FCML_OP_OPERAND_ISx_BASE    0x0C000000
 #define FCML_OP_OPERAND_IS4         (FCML_OP_OPERAND_ISx_BASE | FCML_ISF_IS4)
-
 #define FCML_OP_OPERAND_IS5(flags)  (FCML_OP_OPERAND_ISx_BASE | FCML_ISF_IS5 | \
         flags)
 
@@ -441,6 +441,7 @@ fcml_usize fcml_fn_def_vsib_reg_to_ds(fcml_uint8_t vsib_reg);
 
 #define FCML_SEG_ALLOW_OVERRIDE                      0x80
 #define FCML_SEG_DENY_OVERRIDE                       0x00
+#define FCML_SEG_GET_REG(encoded_reg)                (encoded_reg & 0x7F)
 #define FCML_SEG_ENCODE_REGISTER(reg_num, override)  (reg_num | override)
 
 #define FCML_SEG_DECODE_IS_OVERRIDE_ALLOWED(encoded) \
@@ -450,8 +451,10 @@ fcml_usize fcml_fn_def_vsib_reg_to_ds(fcml_uint8_t vsib_reg);
     (encoded & ~FCML_SEG_ALLOW_OVERRIDE)
 
 /* Useful macros related to addressing modes.*/
+#define FCMP_DEF_IS_ADDR_MODE(x, y)            ((x) == ((y) >> 24))
 
-#define FCMP_DEF_IS_ADDR_MODE(x, y)                ((x) == ((y) >> 24))
+/* Addressing mode checking macro for not shifted addressing mode codes. */
+#define FCML_IS_ADDR_MODE(mode, code)          (((mode) & (code)) == (code))
 
 /* Shorthands*/
 
@@ -1192,6 +1195,7 @@ fcml_usize fcml_fn_def_vsib_reg_to_ds(fcml_uint8_t vsib_reg);
 #define FCML_OP_IW           FCML_OP_IMM(FCML_EOS_WORD, FCML_EOS_UNDEFINED)
 #define FCML_OP_IW_EX_EOSA   FCML_OP_IMM(FCML_EOS_WORD, FCML_EOS_EOSA)
 #define FCML_OP_ID           FCML_OP_IMM(FCML_EOS_DWORD, FCML_EOS_UNDEFINED)
+/* its used only by MOV for imm64 */
 #define FCML_OP_ID_EX_EOSA   FCML_OP_IMM(FCML_EOS_DWORD, FCML_EOS_EOSA)
 #define FCML_OP_EX_EOSA      FCML_OP_IMM(FCML_EOS_EOSA, FCML_EOS_EOSA)
 #define FCML_OP_IMM_EOSA     FCML_OP_IMM(FCML_EOS_EOSA, FCML_EOS_UNDEFINED)
@@ -1213,8 +1217,9 @@ typedef struct fcml_st_def_decoded_addr_mode {
     fcml_ptr addr_mode_args;
 } fcml_st_def_decoded_addr_mode;
 
-fcml_st_def_decoded_addr_mode* fcml_fn_def_decode_addr_mode_args(
-        fcml_operand_desc encoded_addr_mode, fcml_ceh_error *error);
+fcml_ceh_error fcml_fn_def_decode_addr_mode_args(
+        const fcml_operand_desc encoded_addr_mode,
+        fcml_st_def_decoded_addr_mode **decoded_addr_mode);
 
 void fcml_fnp_def_free_addr_mode(
         fcml_st_def_decoded_addr_mode *decoded_addr_mode);
