@@ -105,7 +105,7 @@ fcml_ceh_error fcml_ifn_modrm_decode_displacement(
     }
 
     if (displacement_extension_size) {
-        fcml_fn_utils_extend_integer(&integer, displacement_extension_size);
+        fcml_fn_utils_extend_int(&integer, displacement_extension_size);
     }
 
     if (displacement) {
@@ -115,7 +115,7 @@ fcml_ceh_error fcml_ifn_modrm_decode_displacement(
     if (offset) {
 
         if (offset_extension_size) {
-            fcml_fn_utils_extend_integer(&integer, offset_extension_size);
+            fcml_fn_utils_extend_int(&integer, offset_extension_size);
         }
 
         error = fcml_fn_utils_integer_to_offset(&integer, offset);
@@ -394,6 +394,14 @@ fcml_ceh_error fcml_ifn_modrm_decode_3264bit(
                 return error;
             }
         }
+
+        /* [EBP] can be only encoded with displacement 0, so do not return
+         * it as it was used only in order to encode [EBP]. */
+        if (effective_address->base.reg == FCML_REG_EBP
+                && is_integer_zero(&(effective_address->displacement))) {
+            fcml_fn_env_memory_clear(&(effective_address->displacement), 
+                sizeof(fcml_st_integer));
+        }
     }
 
     /* Decodes register if something needs it.*/
